@@ -1,8 +1,8 @@
-__version__ = '1.18.1'
+__version__ = '1.21.0'
 Version = __version__  # for backward compatibility
 __all__ = ["PopbillException", "JoinForm", "ContactInfo", "CorpInfo",
            "TaxinvoiceService", "Taxinvoice", "TaxinvoiceDetail", "Contact",
-           "FaxService", "FaxReceiver",
+           "FaxService", "FaxReceiver", "FileData",
            "StatementService", "Statement", "StatementDetail",
            "CashbillService", "Cashbill",
            "MessageService", "MessageReceiver",
