@@ -7,14 +7,17 @@
 # Author : Kim Seongjun (pallet027@gmail.com)
 # Written : 2015-01-21
 # Contributor : Jeong Yohan (code@linkhub.co.kr)
-# Updated : 2020-07-16
+# Updated : 2021-04-21
 # Thanks for your interest.
 from io import BytesIO
 import json
 import zlib
+import base64
+
 from time import time as stime
 from json import JSONEncoder
 from collections import namedtuple
+from hashlib import sha1
 
 try:
     import http.client as httpclient
@@ -148,6 +151,32 @@ class PopbillBase(__with_metaclass(Singleton, object)):
         result = self._httpget('/?TG=' + ToGo, CorpNum, UserID)
         return result.url
 
+    def getPaymentURL(self, CorpNum, UserID=None):
+        """ 포인트 결재내역 URL
+            args
+                CorpNum : 회원 사업자번호
+                UserID  : 회원 팝빌아이디
+            return
+                30초 보안 토큰을 포함한 url
+            raise
+                PopbillException
+        """
+        result = self._httpget('/?TG=PAYMENT', CorpNum, UserID)
+        return result.url
+
+    def getUseHistoryURL(self, CorpNum, UserID=None):
+        """ 포인트 사용내역 URL
+            args
+                CorpNum : 회원 사업자번호
+                UserID  : 회원 팝빌아이디
+            return
+                30초 보안 토큰을 포함한 url
+            raise
+                PopbillException
+        """
+        result = self._httpget('/?TG=USEHISTORY', CorpNum, UserID)
+        return result.url
+
     def getAccessURL(self, CorpNum, UserID):
         """ 팝빌 로그인 URL
             args
@@ -215,6 +244,20 @@ class PopbillBase(__with_metaclass(Singleton, object)):
 
         return self._httpget('/IDCheck?ID=' + checkID)
 
+    def getContactInfo(self, CorpNum, ContactID, UserID=None):
+        """ 담당자 정보 확인
+            args
+                CorpNum : 회원 사업자번호
+                ContactID : 확인할 담당자 아이디
+                UserID : 회원 아이디
+        """
+        if ContactID == None or ContactID == '':
+            raise PopbillException(-99999999, "담당자 아이디가 입력되지 않았습니다.")
+
+        postData = "{'id':" + "'" + ContactID + "'}"
+
+        return self._httppost('/Contact', postData, CorpNum, UserID)
+
     def listContact(self, CorpNum, UserID=None):
         """ 담당자 목록 확인
             args
@@ -376,6 +419,40 @@ class PopbillBase(__with_metaclass(Singleton, object)):
         else:
             return Utils.json2obj(responseString)
 
+    def _httpBulkPost(self, url, postData, SubmitID, CorpNum=None, UserID=None, ActionOverride=None):
+        conn = self._getConn()
+
+        headers = {"x-pb-version": APIVersion}
+
+        headers["Content-Type"] = "application/json; charset=utf8"
+
+        headers["x-pb-message-digest"] = base64.b64encode(sha1(postData).digest()).decode('utf-8')
+        headers["x-pb-submit-id"] = SubmitID
+
+        if CorpNum != None:
+            headers["Authorization"] = "Bearer " + self._getToken(CorpNum).session_token
+        if UserID != None:
+            headers["x-pb-userid"] = UserID
+
+        if ActionOverride != None:
+            headers["X-HTTP-Method-Override"] = ActionOverride
+
+        headers["Accept-Encoding"] = "gzip,deflate"
+
+        conn.request('POST', url, postData, headers)
+
+        response = conn.getresponse()
+        responseString = response.read()
+
+        if Utils.isGzip(response, responseString):
+            responseString = Utils.gzipDecomp(responseString)
+
+        if response.status != 200:
+            err = Utils.json2obj(responseString)
+            raise PopbillException(int(err.code), err.message)
+        else:
+            return Utils.json2obj(responseString)
+
     def _httppost_files(self, url, postData, Files, CorpNum, UserID=None):
 
         conn = self._getConn()
